# AMPS Python

This package serves as an interface to the [Agile Message Processing System (AMPS)]() by providing Action, Endpoint, and Service classes that can be used in AMPS Actions, Gateways, and Custom Services, respectively. 

The package documentation is available [here](https://mft-labs.github.io/amps-py)